Module init
rorm
0.10.0
Module init
Module Items
Functions
In rorm::
cli
rorm
::
cli
Module
init
Available on
crate feature
cli
only.
This module is used for creating a configuration file that can be used by the binary version.
Functions

init
Create the database configuration file